# py-minisam
[![Ubuntu Build Status](https://github.com/powei-lin/py-minisam/workflows/ubuntu/badge.svg)](https://github.com/powei-lin/py-minisam/actions?query=workflow%3Aubuntu)

[![PyPI - Version](https://img.shields.io/pypi/v/py-minisam.svg)](https://pypi.org/project/py-minisam)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/py-minisam.svg)](https://pypi.org/project/py-minisam)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install py-minisam
```

## License

`py-minisam` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
